/* Argument checker for ln */
#include <string.h>
#include <unistd.h>
#include <stdlib.h>

char *progname = "ln";

/*D

  ptln - SUT ln

Description:

ptln makes links on specified hosts.

Command Line Arguments:

ptln [-m <machine_file>|-M <machine_list>] [-sfn] <source> [<dest1> [<dest2> [...]]]

.N machine_args
. -s - make symbolic links
. -f - force (delete any existing destination files)
. -n - do not force if a file exists with the same path as a destination
. <source> - the source file
- [<dest1> [<dest2> [...]]] - the destination link names (optional)

Environment Variables:

.N machine_envs

Examples:

To create a symbolic link "edit" to "/bin/vi" on the machines specified in the 
file "destination_machines" use

.vb
ptln -m destination_machines -s /bin/vi edit
.ve

To do the same linking, specifying the machines on the command line, use

.vb
ptln -M "host1 host2 host3" -s /bin/vi edit
.ve

To create a hard link from /homes/johndoe/myfile to /homes/johndoe/tmp/myfile,
use

.vb
ptln -m destination_machines /homes/johndoe/myfile /homes/johndoe/tmp/myfile
.ve

.seealno ln(1)
  
 D*/
int check_args(int argc, char *argv[])
{
    int c;

    while ((c = getopt(argc, argv, "sfn")) != -1){
        switch (c) {
            case 's':
            case 'f':
            case 'n':
                continue;
            default:
                return -1;
        }
    }

    /* Make sure there is a source file */
    if (argc - optind < 1)
        return -1;

    return 0;
}
