#include "mpi.h"
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif /* HAVE_CONFIG_H */

/* ptpred's man page is here because doctext doesn't do shell scripts */
/*D
  
  ptpred - SUT predicate

Description:
ptpred executes test (1) on specified machines and outputs a hostname 
followed by a given string based on the result of the test on that host.

Command Line Arguments:

ptpred [-all|-m <machine_file>|-M <machine_list>] <arguments to test> [<then clause>] [<else clause>]

.N machine_args

. <arguments to test> - the arguments to pass to test
. <then clause> - the string to print if test returns 0 on the given node.  If this is not specified, it is assumed to be "1".
- <else clause> - the string to print if test does not return 0 on the given node.  If this is not specified, it is assumed to be "0".

Environment Variables:

.N machine_envs

Examples:

To test for the existence of the file /home/johndoe/myfile on the machines 
specified in the file "destination_machines" use

.vb
ptpred -m destination_machines -f /home/johndoe/myfile
.ve

To do the same test, specifying machines on the command line, use

.vb
ptpred -M "host1 host2 host3" -f /home/johndoe/myfile
.ve

The output from this command might look like the following\:

.vb
host1.domain.tld: 0
host2.domain.tld: 1
host3.domain.tld: 0
.ve

In this case, /home/johndoe/myfile exists only on host2.

To test on similarly named hosts as in the previous example, an abbreviation
can be used

.vb
ptpred -M "host%d@1-3" -f /home/johndoe/myfile
.ve

where the %d is replaced by the numbers 1-3 when the test is performed.

.seealso: test (1), ptdisp (1)

D*/

/*D
  
  pttest[oa] - SUT test

Description:
pttesto executes test (1) on specifies machines and has an exit value which is
the logical OR of the test results.  

pttesta executes test (1) on specifies machines and has an exit value which is
the logical AND of the test results.  

pttest is a symbolic link to pttesto.

Command Line Arguments:

pttest[ao] [-all|-m <machine_file>|-M <machine_list>] <arguments to test>

.N machine_args

- <arguments to test> - the arguments to pass to test

Environment Variables:

.N machine_envs

Examples:

To test for the existence of the file /home/johndoe/myfile on the machines 
specified in the file "destination_machines" use

.vb
pttest -m destination_machines -f /home/johndoe/myfile
.ve

If /home/johndoe/myfile is missing on any node, pttest will have an exit
code of 1.

To do the same test, specifying machines on the command line, use

.vb
pttest -M "host1 host2 host3" -f /home/johndoe/myfile
.ve

To test on similarly named hosts as in the previous example, an abbreviation
can be used

.vb
pttest -M "host%d@1-3" -f /home/johndoe/myfile
.ve

where the %d is replaced by the numbers 1-3 when the test is performed.

.seealso: test (1)

D*/

int main(int argc, char *argv[])
{
    int rank, status = 0, global_status;

    MPI_Init(&argc, &argv);
    MPI_Comm_rank(MPI_COMM_WORLD, &rank);

    status = system(argv[1]);

    MPI_Allreduce(&status, &global_status, 1, MPI_INT, PT_OP, MPI_COMM_WORLD);
    if (rank == 0)
        printf("%d\n", global_status);

    MPI_Finalize();
    return 0;
}
